@@ -81,6 +81,9 @@ private:
 
     QIcon m_keepFlagIcon;
     std::vector<boost::shared_ptr<const Akregator::Filters::AbstractMatcher> > m_matchers;
+
+    QColor m_unreadColor;
+    QColor m_newColor;
 };
 
 
@@ -139,6 +142,10 @@ public Q_SLOTS:
 
     void slotNextUnreadArticle();
 
+Q_SIGNALS:
+
+    void userActionTakingPlace();
+
 private:
     void saveHeaderSettings();
     void loadHeaderSettings();
