@@ -22,8 +22,9 @@
     without including the source code for Qt in the source distribution.
 */
 
-#include "subscriptionlistmodel.h"
 #include "subscriptionlistview.h"
+#include "subscriptionlistmodel.h"
+#include "subscriptionlistdelegate.h"
 #include "akregatorconfig.h"
 
 #include <QHeaderView>
@@ -39,9 +40,7 @@
 
 using namespace Akregator;
 
-namespace {
-
-QModelIndex prevIndex( const QModelIndex& idx )
+static QModelIndex prevIndex( const QModelIndex& idx )
 {
     if ( !idx.isValid() )
         return QModelIndex();
@@ -60,7 +59,7 @@ QModelIndex prevIndex( const QModelIndex& idx )
 }
 
 
-QModelIndex prevFeedIndex( const QModelIndex& idx, bool allowPassed = false )
+static QModelIndex prevFeedIndex( const QModelIndex& idx, bool allowPassed = false )
 {
     QModelIndex prev = allowPassed ? idx : prevIndex( idx );
     while ( prev.isValid() && prev.data( SubscriptionListModel::IsAggregationRole ).toBool() )
@@ -68,7 +67,7 @@ QModelIndex prevFeedIndex( const QModelIndex& idx, bool allowPassed = false )
     return prev;
 }
 
-QModelIndex prevUnreadFeedIndex( const QModelIndex& idx, bool allowPassed = false )
+static QModelIndex prevUnreadFeedIndex( const QModelIndex& idx, bool allowPassed = false )
 {
     QModelIndex prev = allowPassed ? idx : prevIndex( idx );
     while ( prev.isValid() && ( prev.data( SubscriptionListModel::IsAggregationRole ).toBool() || prev.sibling( prev.row(), SubscriptionListModel::UnreadCountColumn ).data().toInt() == 0 ) )
@@ -76,7 +75,7 @@ QModelIndex prevUnreadFeedIndex( const QModelIndex& idx, bool allowPassed = fals
     return prev;
 }
 
-QModelIndex lastLeaveChild( const QAbstractItemModel* const model )
+static QModelIndex lastLeaveChild( const QAbstractItemModel* const model )
 {
     assert( model );
     if ( model->rowCount() == 0 )
@@ -87,7 +86,7 @@ QModelIndex lastLeaveChild( const QAbstractItemModel* const model )
     return idx;
 }
 
-QModelIndex nextIndex( const QModelIndex& idx )
+static QModelIndex nextIndex( const QModelIndex& idx )
 {
     if ( !idx.isValid() )
         return QModelIndex();
@@ -107,7 +106,7 @@ QModelIndex nextIndex( const QModelIndex& idx )
     }
 }
 
-QModelIndex nextFeedIndex( const QModelIndex& idx )
+static QModelIndex nextFeedIndex( const QModelIndex& idx )
 {
     QModelIndex next = nextIndex( idx );
     while ( next.isValid() && next.data( SubscriptionListModel::IsAggregationRole ).toBool() )
@@ -115,7 +114,7 @@ QModelIndex nextFeedIndex( const QModelIndex& idx )
     return next;
 }
 
-QModelIndex nextUnreadFeedIndex( const QModelIndex& idx )
+static QModelIndex nextUnreadFeedIndex( const QModelIndex& idx )
 {
     QModelIndex next = nextIndex( idx );
     while ( next.isValid() && ( next.data( SubscriptionListModel::IsAggregationRole ).toBool() || next.sibling( next.row(), SubscriptionListModel::UnreadCountColumn ).data().toInt() == 0 ) )
@@ -123,10 +122,9 @@ QModelIndex nextUnreadFeedIndex( const QModelIndex& idx )
     return next;
 }
 
-}
-
 Akregator::SubscriptionListView::SubscriptionListView( QWidget* parent ) : QTreeView( parent )
 {
+    setFocusPolicy( Qt::NoFocus );
     setSelectionMode( QAbstractItemView::SingleSelection );
     setRootIsDecorated( false );
     setAlternatingRowColors( true );
@@ -134,6 +132,8 @@ Akregator::SubscriptionListView::SubscriptionListView( QWidget* parent ) : QTree
     setDragDropMode( QAbstractItemView::DragDrop );
     setDropIndicatorShown( true );
     setAcceptDrops( true );
+    setUniformRowHeights( true );
+    setItemDelegate( new SubscriptionListDelegate( this ) );
     connect( header(), SIGNAL( customContextMenuRequested( const QPoint & ) ), this, SLOT( showHeaderMenu( const QPoint& ) ) );
 
     loadHeaderSettings();
@@ -151,8 +151,11 @@ void Akregator::SubscriptionListView::setModel( QAbstractItemModel* m )
 
     QTreeView::setModel( m );
 
-    if ( m )
+    if ( m ) {
         header()->restoreState( m_headerState );
+        // Always shows title column
+        header()->showSection( SubscriptionListModel::TitleColumn );
+    }
 
     QStack<QModelIndex> stack;
     stack.push( rootIndex() );
@@ -184,6 +187,9 @@ void Akregator::SubscriptionListView::showHeaderMenu( const QPoint& pos )
 
     for (int i = 0; i < model()->columnCount(); i++)
     {
+        if ( SubscriptionListModel::TitleColumn == i ) {
+            continue;
+        }
         QString col = model()->headerData( i, Qt::Horizontal, Qt::DisplayRole ).toString();
         QAction* act = menu->addAction( col );
         act->setCheckable( true );
@@ -216,6 +222,9 @@ void Akregator::SubscriptionListView::loadHeaderSettings()
 {
     const KConfigGroup conf( Settings::self()->config(), "General" );
     m_headerState = QByteArray::fromBase64( conf.readEntry( "SubscriptionListHeaders" ).toAscii() );
+    header()->restoreState( m_headerState );		// needed, even with Qt 4.5
+    // Always shows the title column
+    header()->showSection( SubscriptionListModel::TitleColumn );
 }
 
 void Akregator::SubscriptionListView::slotPrevFeed()
@@ -237,6 +246,7 @@ void Akregator::SubscriptionListView::slotNextFeed()
 {
     if ( !model() )
         return;
+    emit userActionTakingPlace();
     const QModelIndex current = currentIndex();
     QModelIndex next = nextFeedIndex( current );
     if ( !next.isValid() )
@@ -249,6 +259,7 @@ void Akregator::SubscriptionListView::slotPrevUnreadFeed()
 {
     if ( !model() )
         return;
+    emit userActionTakingPlace();
     const QModelIndex current = currentIndex();
     QModelIndex prev = prevUnreadFeedIndex( current );
     if ( !prev.isValid() )
@@ -261,6 +272,7 @@ void Akregator::SubscriptionListView::slotNextUnreadFeed()
 {
     if ( !model() )
         return;
+    emit userActionTakingPlace();
     const QModelIndex current = currentIndex();
     QModelIndex next = nextUnreadFeedIndex( current );
     if ( !next.isValid() )
@@ -271,31 +283,70 @@ void Akregator::SubscriptionListView::slotNextUnreadFeed()
 
 void SubscriptionListView::slotItemBegin()
 {
-
+    if ( !model() )
+        return;
+    emit userActionTakingPlace();
+    setCurrentIndex( nextFeedIndex( model()->index( 0, 0 ) ) );
 }
 
 void SubscriptionListView::slotItemEnd()
 {
+    if ( !model() )
+        return;
+    emit userActionTakingPlace();
+    setCurrentIndex( lastLeaveChild( model() ) );
 }
 
 void SubscriptionListView::slotItemLeft()
 {
-
+    if ( !model() )
+        return;
+    emit userActionTakingPlace();
+    const QModelIndex current = currentIndex();
+    if ( !current.isValid() ) {
+        setCurrentIndex( nextFeedIndex( model()->index( 0, 0 ) ) );
+        return;
+    }
+    if ( current.parent().isValid() )
+        setCurrentIndex( current.parent() );
 }
 
 void SubscriptionListView::slotItemRight()
 {
-
+    if ( !model() )
+        return;
+    emit userActionTakingPlace();
+    const QModelIndex current = currentIndex();
+    if ( !current.isValid() ) {
+        setCurrentIndex( nextFeedIndex( model()->index( 0, 0 ) ) );
+        return;
+    }
+    if ( model()->rowCount( current ) > 0 )
+        setCurrentIndex( current.child( 0, 0 ) );
 }
 
 void SubscriptionListView::slotItemUp()
 {
-
+    if ( !model() )
+        return;
+    emit userActionTakingPlace();
+    const QModelIndex current = currentIndex();
+    QModelIndex prev = current.row() > 0 ? current.sibling( current.row() - 1, current.column() ) : current.parent();
+    if ( !prev.isValid() )
+        prev = lastLeaveChild( model() );
+    if ( prev.isValid() )
+        setCurrentIndex( prev );
 }
 
 void SubscriptionListView::slotItemDown()
 {
-
+    if ( !model() )
+        return;
+    emit userActionTakingPlace();
+    const QModelIndex current = currentIndex();
+    if ( current.row() >= model()->rowCount( current.parent() ) )
+        return;
+    setCurrentIndex( current.sibling( current.row() + 1, current.column() ) );
 }
 
 
