@@ -27,7 +27,6 @@
 #include <kabc/addressee.h>
 
 #include "printstyle.h"
-#include "kabentrypainter.h"
 
 class QPrinter;
 
@@ -40,26 +39,19 @@ class DetailledPrintStyle : public PrintStyle
   Q_OBJECT
 
   public:
-    DetailledPrintStyle( PrintingWizard *parent, const char *name = 0 );
+    explicit DetailledPrintStyle( PrintingWizard *parent );
     ~DetailledPrintStyle();
 
     void print( const KABC::Addressee::List &contacts, PrintProgress* );
 
-  protected:
-    bool printEntries( const KABC::Addressee::List &contacts, QPrinter *printer,
-                       QPainter *painter, const QRect &window );
-    bool printEntry( const KABC::Addressee &contact, const QRect &window,
-                     QPainter *painter, int top, bool fake, QRect *brect );
   private:
     AppearancePage *mPageAppearance;
-    KABEntryPainter *mPainter;
-    PrintProgress *mPrintProgress;
 };
 
 class DetailledPrintStyleFactory : public PrintStyleFactory
 {
   public:
-    DetailledPrintStyleFactory( PrintingWizard *parent, const char *name = 0 );
+    explicit DetailledPrintStyleFactory( PrintingWizard *parent );
 
     PrintStyle *create() const;
     QString description() const;
