@@ -55,6 +55,7 @@
 #include <kio/netaccess.h>
 #include <knotification.h>
 #include <kpushbutton.h>
+#include <ksqueezedtextlabel.h>
 #include <phonon/mediaobject.h>
 #include <phonon/audiooutput.h>
 #include <phonon/volumefadereffect.h>
@@ -166,7 +167,7 @@ MessageWin*           MessageWin::mAudioOwner = 0;
 *  displayed.
 */
 MessageWin::MessageWin(const KAEvent* event, const KAAlarm& alarm, int flags)
-	: MainWindowBase(0, static_cast<Qt::WFlags>(WFLAGS | WFLAGS2 | ((flags & ALWAYS_HIDE) || getWorkAreaAndModal() ? 0 : Qt::X11BypassWindowManagerHint))),
+	: MainWindowBase(0, static_cast<Qt::WFlags>(WFLAGS | WFLAGS2 | ((flags & ALWAYS_HIDE) || getWorkAreaAndModal() ? Qt::WindowType(0) : Qt::X11BypassWindowManagerHint))),
 	  mMessage(event->cleanText()),
 	  mFont(event->font()),
 	  mBgColour(event->bgColour()),
@@ -207,6 +208,7 @@ MessageWin::MessageWin(const KAEvent* event, const KAAlarm& alarm, int flags)
 	  mLateCancel(event->lateCancel()),
 	  mAlwaysHide(flags & ALWAYS_HIDE),
 	  mErrorWindow(false),
+	  mInitialised(false),
 	  mNoPostAction(alarm.type() & KAAlarm::REMINDER_ALARM),
 	  mRecreating(false),
 	  mBeep(event->beep()),
@@ -301,6 +303,7 @@ MessageWin::MessageWin(const KAEvent* event, const DateTime& alarmDateTime,
 	  mDeferDlg(0),
 	  mAlwaysHide(false),
 	  mErrorWindow(true),
+	  mInitialised(false),
 	  mNoPostAction(true),
 	  mRecreating(false),
 	  mRescheduleEvent(false),
@@ -313,7 +316,7 @@ MessageWin::MessageWin(const KAEvent* event, const DateTime& alarmDateTime,
 	setAttribute(static_cast<Qt::WidgetAttribute>(WidgetFlags));
 	setWindowModality(Qt::WindowModal);
 	setObjectName("ErrorWin");    // used by LikeBack
-        getWorkAreaAndModal();
+	getWorkAreaAndModal();
 	initView();
 	mWindowList.append(this);
 }
@@ -336,6 +339,7 @@ MessageWin::MessageWin()
 	  mDeferDlg(0),
 	  mAlwaysHide(false),
 	  mErrorWindow(false),
+	  mInitialised(false),
 	  mRecreating(false),
 	  mRescheduleEvent(false),
 	  mShown(false),
@@ -347,7 +351,7 @@ MessageWin::MessageWin()
 	setAttribute(WidgetFlags);
 	setWindowModality(Qt::WindowModal);
 	setObjectName("RestoredMsgWin");    // used by LikeBack
-        getWorkAreaAndModal();
+	getWorkAreaAndModal();
 	mWindowList.append(this);
 }
 
@@ -421,11 +425,11 @@ void MessageWin::initView()
 			case KAEventData::FILE:
 			{
 				// Display the file name
-				QLabel* label = new QLabel(mMessage, topWidget);
+				KSqueezedTextLabel* label = new KSqueezedTextLabel(mMessage, topWidget);
 				label->setFrameStyle(QFrame::Box | QFrame::Raised);
+				label->setTextInteractionFlags(Qt::TextSelectableByMouse | Qt::TextSelectableByKeyboard);
 				label->setPalette(labelPalette);
 				label->setAutoFillBackground(true);
-				label->setFixedSize(label->sizeHint());
 				label->setWhatsThis(i18nc("@info:whatsthis", "The file whose contents are displayed below"));
 				topLayout->addWidget(label, 0, Qt::AlignHCenter);
 
@@ -747,6 +751,8 @@ void MessageWin::initView()
 	WId winid = winId();
 	KWindowSystem::setState(winid, wstate);
 	KWindowSystem::setOnAllDesktops(winid, true);
+
+	mInitialised = true;   // the window's widgets have been created
 }
 
 /******************************************************************************
@@ -768,7 +774,7 @@ int MessageWin::instanceCount(bool excludeAlwaysHidden)
 
 bool MessageWin::hasDefer() const
 {
-	return mDeferButton->isVisible();
+	return mDeferButton && mDeferButton->isVisible();
 }
 
 /******************************************************************************
@@ -776,9 +782,12 @@ bool MessageWin::hasDefer() const
 */
 void MessageWin::showDefer()
 {
-	mNoDefer = false;
-	mDeferButton->show();
-	resize(sizeHint());
+	if (mDeferButton)
+	{
+		mNoDefer = false;
+		mDeferButton->show();
+		resize(sizeHint());
+	}
 }
 
 /******************************************************************************
@@ -786,6 +795,8 @@ void MessageWin::showDefer()
 */
 void MessageWin::cancelReminder(const KAEvent& event, const KAAlarm& alarm)
 {
+	if (!mInitialised)
+		return;
 	mDateTime = alarm.dateTime(true);
 	mNoPostAction = false;
 	mAlarmType = alarm.type();
@@ -809,6 +820,8 @@ void MessageWin::cancelReminder(const KAEvent& event, const KAAlarm& alarm)
 */
 void MessageWin::showDateTime(const KAEvent& event, const KAAlarm& alarm)
 {
+	if (!mTimeLabel)
+		return;
 	mDateTime = (alarm.type() & KAAlarm::REMINDER_ALARM) ? event.mainDateTime(true) : alarm.dateTime(true);
 	if (mDateTime.isValid())
 	{
@@ -1260,11 +1273,14 @@ bool MessageWin::isSpread(const QPoint& topLeft)
 */
 MessageWin* MessageWin::findEvent(const QString& eventID)
 {
-	for (int i = 0, end = mWindowList.count();  i < end;  ++i)
+	if (!eventID.isEmpty())
 	{
-		MessageWin* w = mWindowList[i];
-		if (w->mEventID == eventID  &&  !w->mErrorWindow)
-			return w;
+		for (int i = 0, end = mWindowList.count();  i < end;  ++i)
+		{
+			MessageWin* w = mWindowList[i];
+			if (w->mEventID == eventID  &&  !w->mErrorWindow)
+				return w;
+		}
 	}
 	return 0;
 }
@@ -1574,6 +1590,8 @@ QString AudioThread::error() const
 */
 void MessageWin::repeat(const KAAlarm& alarm)
 {
+	if (!mInitialised)
+		return;
 	if (mDeferDlg)
 	{
 		// Cancel any deferral dialog so that the user notices something's going on,
