@@ -102,6 +102,7 @@ DistributionListDialog::DistributionListDialog( QWidget *parent )
   setDefaultButton( User1 );
   setModal( false );
   setButtonText( User1, i18nc("@action:button","Save List") );
+  enableButton( User1, false );
 
   QBoxLayout *topLayout = new QVBoxLayout( topFrame );
   topLayout->setSpacing( spacingHint() );
@@ -129,13 +130,15 @@ DistributionListDialog::DistributionListDialog( QWidget *parent )
   topLayout->addWidget( mRecipientsList );
   connect( this, SIGNAL( user1Clicked() ),
            this, SLOT( slotUser1() ) );
+  connect( mTitleEdit, SIGNAL( textChanged( const QString& ) ),
+           this, SLOT( slotTitleChanged( const QString& ) ) );
 }
 
 void DistributionListDialog::setRecipients( const Recipient::List &recipients )
 {
   Recipient::List::ConstIterator it;
   for( it = recipients.constBegin(); it != recipients.constEnd(); ++it ) {
-    QStringList emails = KPIMUtils::splitAddressList( (*it).email() );
+    const QStringList emails = KPIMUtils::splitAddressList( (*it).email() );
     QStringList::ConstIterator it2;
     for( it2 = emails.constBegin(); it2 != emails.constEnd(); ++it2 ) {
       QString name;
@@ -179,11 +182,17 @@ void DistributionListDialog::setRecipients( const Recipient::List &recipients )
   }
 }
 
+void DistributionListDialog::slotTitleChanged( const QString& text )
+{
+  enableButton( KDialog::User1, !text.isEmpty() );
+}
+
 void DistributionListDialog::slotUser1()
 {
   bool isEmpty = true;
 
-  for (int i = 0; i < mRecipientsList->topLevelItemCount(); ++i) {
+  const int numberOfItems = mRecipientsList->topLevelItemCount();
+  for (int i = 0; i < numberOfItems; ++i) {
     DistributionListItem *item = static_cast<DistributionListItem *>(
         mRecipientsList->topLevelItem( i ));
     if ( item && item->checkState( 0 ) == Qt::Checked ) {
@@ -232,7 +241,8 @@ void DistributionListDialog::slotUser1()
 
   KABC::ContactGroup group( name );
 
-  for ( int i = 0; i < mRecipientsList->topLevelItemCount(); ++i ) {
+  const int numberOfTopLevelItems = mRecipientsList->topLevelItemCount();
+  for ( int i = 0; i < numberOfTopLevelItems; ++i ) {
     DistributionListItem *item = static_cast<DistributionListItem *>( mRecipientsList->topLevelItem( i ) );
     if ( item && item->checkState( 0 ) == Qt::Checked ) {
       kDebug() << item->addressee().fullEmail() << item->addressee().uid();
