@@ -45,8 +45,8 @@
 
 #include <kurl.h>
 
-#include <kfoldertree.h>
-using KPIM::KFolderTreeItem;
+#include <libkdepim/foldertreewidget.h>
+
 #include "kmfoldertype.h"
 #include "groupware_types.h"
 
@@ -138,6 +138,10 @@ public:
                       quint32 sernum,
                       const QString& filename );
 
+  QString attachmentMimetype( const QString &resource,
+                              quint32 sernum,
+                              const QString &filename );
+
   QStringList listAttachments( const QString &resource, quint32 sernum );
 
 
@@ -183,17 +187,17 @@ public:
    * Returns the resource folder type. Other is returned if resource
    * isn't enabled or it isn't a resource folder.
    */
-  KFolderTreeItem::Type folderType( KMFolder* folder ) const;
+  KPIM::FolderTreeWidgetItem::FolderType folderType( KMFolder* folder ) const;
 
   /**
    * Returns the name of the standard icon for a folder of given type or
    * QString() if the type is no groupware type.
    */
-  QString folderPixmap( KFolderTreeItem::Type type ) const;
+  QString folderPixmap( KPIM::FolderTreeWidgetItem::FolderType type ) const;
 
   /** Returns the localized name of a folder of given type.
    */
-  QString folderName( KFolderTreeItem::Type type, int language = -1 ) const;
+  QString folderName( KPIM::FolderTreeWidgetItem::FolderType type, int language = -1 ) const;
 
   /** Get the folder that holds *type* entries */
   KMFolder* folderFromType( const QString& type, const QString& folder );
@@ -232,6 +236,7 @@ public:
   // See CachedImapJob::slotPutMessageResult
   bool isResourceQuiet() const;
   void setResourceQuiet(bool q);
+  static QMap<QString, QString>* getResourceMap() { return mSubResourceUINamesMap; }
 
 public slots:
   /* (Re-)Read configuration file */
@@ -245,6 +250,7 @@ public slots:
   // Called when a folder is made readonly or readwrite, or renamed,
   // or any other similar change that affects the resources
   void slotFolderPropertiesChanged( KMFolder* folder );
+  void changeResourceUIName( const QString &folderPath, const QString &newName );
 
 private slots:
   void slotRefreshFolder( KMFolder* );
@@ -281,7 +287,10 @@ private:
     enum FoundEnum { FoundAndStandard, NotFound, FoundByType, FoundByName };
     StandardFolderSearchResult() : folder( 0 ) {}
     StandardFolderSearchResult( KMFolder* f, FoundEnum e ) : folder( f ), found( e ) {}
+    StandardFolderSearchResult( const QList<KMFolder*> &f, FoundEnum e ) :
+        folder( f.first() ), folders( f ), found( e ) {}
     KMFolder* folder; // NotFound implies folder==0 of course.
+    QList<KMFolder*> folders; // in case we found multiple default folders (which should not happen)
     FoundEnum found;
   };
 
@@ -363,7 +372,7 @@ private:
   QMap<quint32, bool> mTheUnGetMes;
   QMap<QString, QString> mPendingUpdates;
   QMap<QString, bool> mInTransit;
-
+  static QMap<QString, QString> *mSubResourceUINamesMap;
 };
 
 #endif // KMAILICALIFACEIMPL_H
