@@ -49,6 +49,7 @@ KMFilter::KMFilter( bool popFilter )
     mAction = Down;
   else {
     bApplyOnInbound = true;
+    bApplyBeforeOutbound = false;
     bApplyOnOutbound = false;
     bApplyOnExplicit = true;
     bStopProcessingHere = true;
@@ -77,6 +78,7 @@ KMFilter::KMFilter( const KMFilter & aFilter )
     mAction = aFilter.mAction;
   } else {
     bApplyOnInbound = aFilter.applyOnInbound();
+    bApplyBeforeOutbound = aFilter.applyBeforeOutbound();
     bApplyOnOutbound = aFilter.applyOnOutbound();
     bApplyOnExplicit = aFilter.applyOnExplicit();
     bStopProcessingHere = aFilter.stopProcessingHere();
@@ -242,11 +244,13 @@ void KMFilter::readConfig(KConfigGroup & config)
   else {
     QStringList sets = config.readEntry("apply-on", QStringList() );
     if ( sets.isEmpty() && !config.hasKey("apply-on") ) {
+      bApplyBeforeOutbound = false;
       bApplyOnOutbound = false;
       bApplyOnInbound = true;
       bApplyOnExplicit = true;
       mApplicability = ButImap;
     } else {
+      bApplyBeforeOutbound = bool(sets.contains("before-send-mail"));
       bApplyOnInbound = bool(sets.contains("check-mail"));
       bApplyOnOutbound = bool(sets.contains("send-mail"));
       bApplyOnExplicit = bool(sets.contains("manual-filtering"));
@@ -331,6 +335,8 @@ void KMFilter::writeConfig(KConfigGroup & config) const
     QStringList sets;
     if ( bApplyOnInbound )
       sets.append( "check-mail" );
+    if ( bApplyBeforeOutbound )
+      sets.append( "before-send-mail" );
     if ( bApplyOnOutbound )
       sets.append( "send-mail" );
     if ( bApplyOnExplicit )
@@ -391,7 +397,8 @@ bool KMFilter::isEmpty() const
   if (bPopFilter)
     return mPattern.isEmpty();
   else
-    return mPattern.isEmpty() && mActions.isEmpty() && mAccounts.isEmpty();
+    return ( mPattern.isEmpty() && mActions.isEmpty() ) ||
+        ( ( applicability() == Checked ) && mAccounts.isEmpty() );
 }
 
 QString KMFilter::toolbarName() const
@@ -427,6 +434,8 @@ const QString KMFilter::asString() const
     result += "This filter belongs to the following sets:";
     if ( bApplyOnInbound )
       result += " Inbound";
+    if ( bApplyBeforeOutbound )
+      result += " before-Outbound";
     if ( bApplyOnOutbound )
       result += " Outbound";
     if ( bApplyOnExplicit )
@@ -441,9 +450,11 @@ const QString KMFilter::asString() const
       result += "This filter applies to the following accounts:";
       if ( mAccounts.isEmpty() )
         result += " None";
-      else for ( it2 = mAccounts.begin() ; it2 != mAccounts.end() ; ++it2 )
-        if ( kmkernel->acctMgr()->find( *it2 ) )
-          result += ' ' + kmkernel->acctMgr()->find( *it2 )->name();
+      else for ( it2 = mAccounts.begin() ; it2 != mAccounts.end() ; ++it2 ) {
+        KMAccount *acct = kmkernel->acctMgr()->find( *it2 );
+        if ( acct )
+          result += ' ' + acct->name();
+      }
       result += '\n';
     }
     if ( bStopProcessingHere )
