@@ -793,6 +793,14 @@ int KMFolderMbox::createIndexFromContents()
       if (line [i] < ' ' && line [i]>0) inHeader = false;
       else if (lastStr) *lastStr += line + i;
     }
+    else if ( inHeader && line[0] == '=' &&
+        ( ( line[1] == '0' && line[2] == '9' ) ||
+          ( line[1] == '2' && line[2] == '0' ) ) )
+    {
+        // bug 86302 - workaround for malformed wrapped encoded-words
+        if (lastStr)
+          *lastStr += line + 3;
+    }
     else lastStr = 0;
 
     if (inHeader && (line [0]=='\n' || line [0]=='\r'))
@@ -1221,16 +1229,16 @@ if( fileD1.open( QIODevice::WriteOnly ) ) {
   return 0;
 }
 
-int KMFolderMbox::compact( unsigned int startIndex, int nbMessages, FILE *tmpfile,
+int KMFolderMbox::compact( int startIndex, int nbMessages, FILE *tmpfile,
                            off_t&offs, bool &done )
 {
   int rc = 0;
   QByteArray mtext;
-  unsigned int stopIndex = nbMessages == -1
+  int stopIndex = nbMessages == -1
                        ? mMsgList.count()
                        : qMin( mMsgList.count(), startIndex + nbMessages );
-  //kDebug() << "KMFolderMbox: compacting from" << startIndex <<" to" << stopIndex;
-  for ( unsigned int idx = startIndex; idx < stopIndex; ++idx ) {
+  //kDebug() << "KMFolderMbox: compacting from" << startIndex << "to" << stopIndex;
+  for ( int idx = startIndex; idx < stopIndex; ++idx ) {
     KMMsgInfo* mi = (KMMsgInfo*)mMsgList.at( idx );
     size_t msize = mi->msgSize();
     if ( (size_t) mtext.size() < msize + 2 ) {
