@@ -23,6 +23,7 @@
 #include "recentaddresses.h"
 #include "kmkernel.h"
 #include "globalsettings.h"
+#include "autoqpointer.h"
 #include "stringutil.h"
 
 #include <libkdepim/kvcarddrag.h>
@@ -49,6 +50,7 @@ KMLineEdit::KMLineEdit(bool useCompletion,
     : KPIM::AddresseeLineEdit(parent,useCompletion)
 {
   setObjectName( name );
+  allowSemiColonAsSeparator( GlobalSettings::allowSemicolonAsAddressSeparator() );
 }
 
 
@@ -175,31 +177,34 @@ void KMLineEdit::contextMenuEvent( QContextMenuEvent*e )
 
 void KMLineEdit::editRecentAddresses()
 {
-  KPIM::RecentAddressDialog dlg( this );
-  dlg.setAddresses( KPIM::RecentAddresses::self( KMKernel::config() )->addresses() );
-  if ( !dlg.exec() )
-    return;
-  KPIM::RecentAddresses::self( KMKernel::config() )->clear();
-  const QStringList addrList = dlg.addresses();
-  for ( QStringList::const_iterator it = addrList.begin(), end = addrList.end() ; it != end ; ++it )
-    KPIM::RecentAddresses::self( KMKernel::config() )->add( *it );
-  loadContacts();
+  AutoQPointer<KPIM::RecentAddressDialog> dlg( new KPIM::RecentAddressDialog( this ) );
+  dlg->setAddresses( KPIM::RecentAddresses::self( KMKernel::config().data() )->addresses() );
+  if ( dlg->exec() && dlg ) {
+    KPIM::RecentAddresses::self( KMKernel::config().data() )->clear();
+    const QStringList addrList = dlg->addresses();
+    for ( QStringList::const_iterator it = addrList.begin(), end = addrList.end() ; it != end ; ++it )
+      KPIM::RecentAddresses::self( KMKernel::config().data() )->add( *it );
+    loadContacts();
+  }
 }
 
 
 //-----------------------------------------------------------------------------
 void KMLineEdit::loadContacts()
 {
-  // was: KABC::AddressLineEdit::loadAddresses()
   AddresseeLineEdit::loadContacts();
 
   if ( GlobalSettings::self()->showRecentAddressesInComposer() ){
     if ( KMKernel::self() ) {
       QStringList recent =
-        KPIM::RecentAddresses::self( KMKernel::config() )->addresses();
+        KPIM::RecentAddresses::self( KMKernel::config().data() )->addresses();
       QStringList::Iterator it = recent.begin();
       QString name, email;
-      int idx = addCompletionSource( i18n( "Recent Addresses" ) );
+
+      KSharedConfig::Ptr config = KSharedConfig::openConfig( "kpimcompletionorder" );
+      KConfigGroup group( config, "CompletionWeights" );
+      int weight = group.readEntry( "Recent Addresses", 10 );
+      int idx = addCompletionSource( i18n( "Recent Addresses" ), weight );
       for ( ; it != recent.end(); ++it ) {
         KABC::Addressee addr;
         KPIMUtils::extractEmailAddressAndName( *it, email, name );
@@ -210,7 +215,7 @@ void KMLineEdit::loadContacts()
         }
         addr.setNameFromString( name );
         addr.insertEmail( email, true );
-        addContact( addr, 120, idx ); // more weight than kabc entries and more than ldap results
+        addContact( addr, weight, idx );
       }
     }
   }
