@@ -33,7 +33,7 @@ using KMail::FilterLog;
 #include <kconfig.h>
 #include <kconfiggroup.h>
 
-#include <kabc/stdaddressbook.h>
+#include <akonadi/contact/contactsearchjob.h>
 
 #include <QRegExp>
 #include <QByteArray>
@@ -372,7 +372,16 @@ bool KMSearchRuleString::matches( const KMMessage * msg ) const
     else
       msgContents += ", " + msg->cc();
     msgContents += ", " + msg->headerField("Bcc");
-  }  else {
+  } else if ( field() == "<tag>" ) {
+    if ( msg->tagList() ) {
+      foreach ( const QString &label, * msg->tagList() ) {
+        const KMMessageTagDescription * tagDesc = kmkernel->msgTagMgr()->find( label );
+        if ( tagDesc )
+          msgContents += tagDesc->name();
+      }
+      logContents = false;
+    }
+  } else {
     // make sure to treat messages with multiple header lines for
     // the same header correctly
     msgContents = msg->headerFields( field() ).join( " " );
@@ -446,26 +455,28 @@ bool KMSearchRuleString::matchesInternal( const QString & msgContents ) const
       return ( QString::compare( msgContents.toLower(), contents().toLower() ) >= 0 );
 
   case FuncIsInAddressbook: {
-    KABC::AddressBook *stdAb = KABC::StdAddressBook::self( true );
-    const QStringList addressList =
-      KPIMUtils::splitAddressList( msgContents.toLower() );
-    for( QStringList::ConstIterator it = addressList.constBegin();
-         ( it != addressList.constEnd() );
-         ++it ) {
-      if ( !stdAb->findByEmail( KPIMUtils::extractEmailAddress( *it ) ).isEmpty() )
+    const QStringList addressList = KPIMUtils::splitAddressList( msgContents.toLower() );
+    for ( QStringList::ConstIterator it = addressList.constBegin(); ( it != addressList.constEnd() ); ++it ) {
+      Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob();
+      job->setLimit( 1 );
+      job->setQuery( Akonadi::ContactSearchJob::Email, KPIMUtils::extractEmailAddress( *it ) );
+      job->exec();
+
+      if ( !job->contacts().isEmpty() )
         return true;
     }
     return false;
   }
 
   case FuncIsNotInAddressbook: {
-    KABC::AddressBook *stdAb = KABC::StdAddressBook::self( true );
-    const QStringList addressList =
-      KPIMUtils::splitAddressList( msgContents.toLower() );
-    for( QStringList::ConstIterator it = addressList.constBegin();
-         ( it != addressList.constEnd() );
-         ++it ) {
-      if ( stdAb->findByEmail( KPIMUtils::extractEmailAddress( *it ) ).isEmpty() )
+    const QStringList addressList = KPIMUtils::splitAddressList( msgContents.toLower() );
+    for ( QStringList::ConstIterator it = addressList.constBegin(); ( it != addressList.constEnd() ); ++it ) {
+      Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob();
+      job->setLimit( 1 );
+      job->setQuery( Akonadi::ContactSearchJob::Email, KPIMUtils::extractEmailAddress( *it ) );
+      job->exec();
+
+      if ( job->contacts().isEmpty() )
         return true;
     }
     return false;
@@ -474,36 +485,41 @@ bool KMSearchRuleString::matchesInternal( const QString & msgContents ) const
   case FuncIsInCategory: {
     QString category = contents();
     const QStringList addressList =  KPIMUtils::splitAddressList( msgContents.toLower() );
-    KABC::AddressBook *stdAb = KABC::StdAddressBook::self( true );
 
-    for( QStringList::ConstIterator it = addressList.constBegin();
-      it != addressList.constEnd(); ++it ) {
-        KABC::Addressee::List addresses = stdAb->findByEmail( KPIMUtils::extractEmailAddress( *it ) );
+    for ( QStringList::ConstIterator it = addressList.constBegin(); it != addressList.constEnd(); ++it ) {
+      Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob();
+      job->setQuery( Akonadi::ContactSearchJob::Email, KPIMUtils::extractEmailAddress( *it ) );
+      job->exec();
 
-          for ( KABC::Addressee::List::Iterator itAd = addresses.begin(); itAd != addresses.end(); ++itAd )
-              if ( (*itAd).hasCategory(category) )
-                return true;
+      const KABC::Addressee::List contacts = job->contacts();
 
+      foreach ( const KABC::Addressee &contact, contacts ) {
+        if ( contact.hasCategory( category ) )
+          return true;
       }
-      return false;
     }
+    return false;
+  }
 
-    case FuncIsNotInCategory: {
-      QString category = contents();
-      const QStringList addressList =  KPIMUtils::splitAddressList( msgContents.toLower() );
-      KABC::AddressBook *stdAb = KABC::StdAddressBook::self( true );
+  case FuncIsNotInCategory: {
+    QString category = contents();
+    const QStringList addressList =  KPIMUtils::splitAddressList( msgContents.toLower() );
 
-      for( QStringList::ConstIterator it = addressList.constBegin();
-        it != addressList.constEnd(); ++it ) {
-          KABC::Addressee::List addresses = stdAb->findByEmail( KPIMUtils::extractEmailAddress( *it ) );
+    for ( QStringList::ConstIterator it = addressList.constBegin(); it != addressList.constEnd(); ++it ) {
+      Akonadi::ContactSearchJob *job = new Akonadi::ContactSearchJob();
+      job->setQuery( Akonadi::ContactSearchJob::Email, KPIMUtils::extractEmailAddress( *it ) );
+      job->exec();
 
-            for ( KABC::Addressee::List::Iterator itAd = addresses.begin(); itAd != addresses.end(); ++itAd )
-                if ( (*itAd).hasCategory(category) )
-                  return false;
+      const KABC::Addressee::List contacts = job->contacts();
 
+      foreach ( const KABC::Addressee &contact, contacts ) {
+        if ( contact.hasCategory( category ) )
+          return false;
       }
-      return true;
+
     }
+    return true;
+  }
   default:
     ;
   }
