@@ -21,7 +21,7 @@
 #define _kmsearchpattern_h_
 
 #include <klocale.h>
-#include <messagestatus.h>
+#include <messagecore/messagestatus.h>
 using KPIM::MessageStatus;
 
 #include <QList>
@@ -137,6 +137,7 @@ public:
       @li \<size\>: Try to match against size of message (numerical).
       @li \<age in days\>: Try to match against age of message (numerical).
       @li \<status\>: Try to match against status of message (status).
+      @li \<tag\>: Try to match against message tags.
   */
   QByteArray field() const { return mField; }
 
