@@ -22,8 +22,8 @@
 #include "messagelistview/pane.h"
 #include "messagelistview/storagemodel.h"
 
-#include "messagelistview/core/view.h"
-#include "messagelistview/core/messageitem.h"
+#include <messagelist/core/view.h>
+#include <messagelist/core/messageitem.h>
 
 #include "kmmessage.h"
 #include "kmfolder.h"
@@ -46,6 +46,7 @@
 #include <KActionMenu>
 #include <KApplication>
 #include <KConfigGroup>
+#include <KComboBox>
 #include <KIconEffect>
 #include <KIconLoader>
 #include <KMenu>
@@ -58,6 +59,8 @@ namespace KMail
 namespace MessageListView
 {
 
+using namespace MessageList;
+
 Widget::Widget( KMMainWidget *mainWidget, Pane *pPane )
   : Core::Widget( pPane ), mPane( pPane ), mMainWidget( mainWidget )
 {
@@ -214,11 +217,6 @@ void Widget::viewMessageStatusChangeRequest( Core::MessageItem *msg, const KPIM:
 }
 
 
-Core::MessageItem * Widget::currentMessageItem() const
-{
-  return view()->currentMessageItem();
-}
-
 Core::MessageItem * Widget::messageItemFromMessage( KMMessage * msg ) const
 {
   return messageItemFromMsgBase( msg );
@@ -250,6 +248,7 @@ Core::MessageItem * Widget::messageItemFromMsgBase( KMMsgBase * msg ) const
   if ( !storageModel() )
     return 0;
 
+  // The call below is expensive: it's a linear search.
   int row = static_cast< StorageModel * >( storageModel() )->msgBaseRow( msg );
   if ( row < 0 )
     return 0;
@@ -260,16 +259,31 @@ Core::MessageItem * Widget::messageItemFromMsgBase( KMMsgBase * msg ) const
 void Widget::activateMessageItemByMsgBase( KMMsgBase * msg )
 {
   // This function may be expensive since it needs to perform a linear search
-  // in the storage. We want to avoid that so we use some tricks.
+  // in the storage. We want to avoid that as much as possible so we use some tricks.
 
   if ( !storageModel() )
     return;
 
+  if( view()->model()->isLoading() ) // unlikely
+  {
+    // Strange things may happen if this function is called while
+    // the view is still loading. This isn't very likely but may happen
+    // with the search dialog in certain conditions.
+    //
+    // We must ask the model to do the job later.
+
+    int row = static_cast< StorageModel * >( storageModel() )->msgBaseRow( msg );
+    if ( row < 0 )
+      return; // not in this Folder...err...StorageModel ?
+
+    view()->model()->activateMessageAfterLoading( msg->getMsgSerNum(), row );
+    return;
+  }
 
   Core::MessageItem * mi = 0;
 
   // take care of current first
-  if ( currentMsgBase() != msg ) // this 
+  if ( currentMsgBase() != msg ) // this
   {
     mi = messageItemFromMsgBase( msg );
 
@@ -417,7 +431,7 @@ MessageTreeCollection * Widget::itemListToMessageTreeCollection( const QList< Co
 
     if ( !attached )
       collection->addTree( tree );
-  }  
+  }
 
   return collection;
 }
@@ -509,7 +523,7 @@ QList< KMMsgBase * > Widget::persistentSetContentsAsMsgBaseList( Core::MessageIt
     ret.append( msg );
   }
 
-  return ret;  
+  return ret;
 }
 
 void Widget::markPersistentSetAsAboutToBeRemoved( Core::MessageItemSetReference ref, bool bMark )
@@ -605,7 +619,7 @@ void Widget::viewMessageListContextPopupRequest( const QList< Core::MessageItem
 
   Q_ASSERT( storageModel() );
 
-  mMainWidget->updateMessageMenu(); 
+  mMainWidget->updateMessageMenu();
   //mMainWidget->updateMessageActions(); <-- this is called by updateMessageMenu()
 
   KMenu menu( this );
@@ -847,7 +861,7 @@ void Widget::viewDropEvent( QDropEvent *e )
       // FIXME: This code is duplicated almost exactly in FolderView... shouldn't we share ?
       // FIXME: anybody sets this option to false ?
       if ( GlobalSettings::self()->showPopupAfterDnD() )
-      { 
+      {
         KMenu menu;
         QAction *moveAction = menu.addAction( KIcon( "go-jump"), i18n( "&Move Here" ) );
         QAction *copyAction = menu.addAction( KIcon( "edit-copy" ), i18n( "&Copy Here" ) );
@@ -892,7 +906,7 @@ void Widget::viewJobBatchTerminated()
   mPane->widgetIconChangeRequest( this, mFolderIconBase );
 }
 
-QActionGroup * Widget::fillMessageTagMenu( KMenu * menu )
+void Widget::fillMessageTagCombo( KComboBox * combo )
 {
   // Used for sorting, go through this routine so that mMsgTagList is properly ordered
   KMMessageTagList sortedTags;
@@ -906,31 +920,19 @@ QActionGroup * Widget::fillMessageTagMenu( KMenu * menu )
   }
 
   if ( sortedTags.isEmpty() )
-    return 0;
+    return;
 
   sortedTags.prioritySort();
 
-  QActionGroup * grp = new QActionGroup( menu );
-
-  QAction * act;
-
-  QString currentTagId = currentFilterTagId();
-
   for ( KMMessageTagList::Iterator itl = sortedTags.begin(); itl != sortedTags.end(); ++itl )
   {
     const KMMessageTagDescription *description = kmkernel->msgTagMgr()->find( *itl );
     if ( description )
     {
-      act = menu->addAction( description->name() );
-      act->setIcon( SmallIcon( description->toolbarIconName() ) );
-      act->setCheckable( true );
-      act->setChecked( description->label() == currentTagId );
-      act->setData( QVariant( description->label() ) );
-      grp->addAction( act );
+      combo->addItem( SmallIcon( description->toolbarIconName() ), description->name(),
+                      QVariant( description->label() ) );
     }
   }
-
-  return grp;
 }
 
 
