@@ -38,6 +38,7 @@
 using KPIM::AddressesDialog;
 #include "recentaddresses.h"
 using KPIM::RecentAddresses;
+#include "autoqpointer.h"
 
 #include <kiconloader.h>
 #include <klocale.h>
@@ -79,6 +80,7 @@ RedirectDialog::RedirectDialog( QWidget *parent, bool immediate )
 
   connect( mBtnTo, SIGNAL(clicked()), SLOT(slotAddrBook()) );
 
+  connect( mEditTo, SIGNAL( textChanged ( const QString & ) ), SLOT( slotEmailChanged( const QString & ) ) );
   mLabelTo->setBuddy( mBtnTo );
   mEditTo->setFocus();
 
@@ -86,9 +88,17 @@ RedirectDialog::RedirectDialog( QWidget *parent, bool immediate )
   setButtonGuiItem( User2, KGuiItem( i18n("Send &Later"), "mail-queue" ) );
   connect(this,SIGNAL(user1Clicked()),this, SLOT(slotUser1()));
   connect(this,SIGNAL(user2Clicked()),this, SLOT(slotUser2()));
+  enableButton( User1, false );
+  enableButton( User2, false );
 }
 
 
+void RedirectDialog::slotEmailChanged( const QString & text )
+{
+  enableButton( User1, !text.isEmpty() );
+  enableButton( User2, !text.isEmpty() );
+}
+
 //-----------------------------------------------------------------------------
 void RedirectDialog::slotUser1()
 {
@@ -119,26 +129,25 @@ void RedirectDialog::accept()
 //-----------------------------------------------------------------------------
 void RedirectDialog::slotAddrBook()
 {
-  AddressesDialog dlg( this );
+  AutoQPointer<AddressesDialog> dlg( new AddressesDialog( this ) );
 
   mResentTo = mEditTo->text();
   if ( !mResentTo.isEmpty() ) {
       QStringList lst = KPIMUtils::splitAddressList( mResentTo );
-      dlg.setSelectedTo( lst );
+      dlg->setSelectedTo( lst );
   }
 
-  dlg.setRecentAddresses(
-      RecentAddresses::self( KMKernel::config() )->kabcAddresses() );
+  dlg->setRecentAddresses( RecentAddresses::self( KMKernel::config().data() )->kabcAddresses() );
 
   // Make it impossible to specify Cc or Bcc addresses as we support
   // only the Redirect-To header!
-  dlg.setShowCC( false );
-  dlg.setShowBCC( false );
+  dlg->setShowCC( false );
+  dlg->setShowBCC( false );
 
-  if (dlg.exec()==KDialog::Rejected) return;
-
-  mEditTo->setText( dlg.to().join(", ") );
-  mEditTo->setModified( true );
+  if ( dlg->exec() != KDialog::Rejected && dlg ) {
+    mEditTo->setText( dlg->to().join(", ") );
+    mEditTo->setModified( true );
+  }
 }
 
 
