@@ -88,11 +88,6 @@ namespace KMail {
       void slotListDirectory(const QStringList&, const QStringList&,
           const QStringList&, const QStringList&, const ImapAccountBase::jobData &);
 
-      /**
-       * called by Ok-button, saves the changes
-       */
-      void slotSave();
-
       /**
        * Called from the account when a connection was established
        */
@@ -105,9 +100,21 @@ namespace KMail {
       void slotLoadFolders();
 
     protected:
+
+      /**
+       * Reimplemented from KDialog to call doSave() when the OK button is clicked.
+       * This makes it possible to keep the dialog open after the user canceled the dialog
+       * from checkIfSubscriptionsEnabled().
+       */
+      virtual void slotButtonClicked( int button );
+
       virtual void listAllAvailableAndCreateItems() = 0;
       virtual void processFolderListing() = 0;
-      virtual void doSave() = 0;
+
+      /**
+       * @return false is saving was canceled by the user
+       */
+      virtual bool doSave() = 0;
 
       // helpers
       /** Move all child items of @param oldItem under @param item */
@@ -117,9 +124,23 @@ namespace KMail {
        * folders. */
       void createListViewItem( int i );
 
-      /** If subscriptions are not used for the server, 
-       *  asks "Do you want to enable subscriptions?" */
-      void checkIfSubscriptionsEnabled();
+      /**
+       * If subscriptions are not enabled it
+       * shows a messagebox which asks to user to enable the option.
+       *
+       * If the subscriptions should be enabled, this method will set
+       * mForceSubscriptionEnable to true, otherwise to false.
+       *
+       * This function calls subscriptionOptionEnabled() to check if the option
+       * is currently enabled and subscriptionOptionQuestion() to get the text for
+       * the messagebox.
+       *
+       * @return false if the user clicked cancel, true otherwise
+       */
+      bool checkIfSubscriptionsEnabled();
+
+      virtual bool subscriptionOptionEnabled( const KMail::ImapAccountBase *account ) const = 0;
+      virtual QString subscriptionOptionQuestion( const QString &accountName ) const = 0;
 
       QString mDelimiter;
       QStringList mFolderNames, mFolderPaths,
@@ -149,7 +170,11 @@ namespace KMail {
       /** reimpl */
       virtual void processFolderListing();
       /** reimpl */
-      virtual void doSave();
+      virtual bool doSave();
+      /** reimpl */
+      virtual bool subscriptionOptionEnabled( const KMail::ImapAccountBase *account ) const;
+      /** reimpl */
+      virtual QString subscriptionOptionQuestion( const QString &accountName ) const;
 
     private:
       /**
