@@ -1,8 +1,6 @@
 /*
-    kngroupselectdialog.cpp
-
     KNode, the KDE newsreader
-    Copyright (c) 1999-2001 the KNode authors.
+    Copyright (c) 1999-2006 the KNode authors.
     See file AUTHORS for details
 
     This program is free software; you can redistribute it and/or modify
@@ -14,40 +12,38 @@
     Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, US
 */
 
-#include <qlayout.h>
-#include <qlabel.h>
-#include <qheader.h>
-#include <qcheckbox.h>
+#include <q3header.h>
+#include <QCheckBox>
 
 #include <klocale.h>
 #include <kmessagebox.h>
 
 #include "utilities.h"
 #include "kngroupselectdialog.h"
-#include <qpushbutton.h>
+#include <QPushButton>
 
 
 KNGroupSelectDialog::KNGroupSelectDialog(QWidget *parent, KNNntpAccount *a, const QString &act) :
   KNGroupBrowser(parent, i18n("Select Destinations"), a)
 {
-  selView=new QListView(page);
-  selView->addColumn(QString::null);
+  selView=new Q3ListView(page);
+  selView->addColumn( QString() );
   selView->header()->hide();
   listL->addWidget(selView, 1,2);
   rightLabel->setText(i18n("Groups for this article:"));
   subCB->setChecked(true);
 
   KNGroupInfo info;
-  QStringList actGroups = QStringList::split(',',act);
+  QStringList actGroups = act.split(',',QString::SkipEmptyParts);
   for ( QStringList::Iterator it = actGroups.begin(); it != actGroups.end(); ++it ) {
     info.name = *it;
     new GroupItem(selView, info);
   }
 
-  connect(selView, SIGNAL(selectionChanged(QListViewItem*)),
-    this, SLOT(slotItemSelected(QListViewItem*)));
-  connect(groupView, SIGNAL(selectionChanged(QListViewItem*)),
-    this, SLOT(slotItemSelected(QListViewItem*)));
+  connect(selView, SIGNAL(selectionChanged(Q3ListViewItem*)),
+    this, SLOT(slotItemSelected(Q3ListViewItem*)));
+  connect(groupView, SIGNAL(selectionChanged(Q3ListViewItem*)),
+    this, SLOT(slotItemSelected(Q3ListViewItem*)));
   connect(groupView, SIGNAL(selectionChanged()),
     this, SLOT(slotSelectionChanged()));
   connect(arrowBtn1, SIGNAL(clicked()), this, SLOT(slotArrowBtn1()));
@@ -88,14 +84,14 @@ void KNGroupSelectDialog::updateItemState(CheckItem *it)
 QString KNGroupSelectDialog::selectedGroups()const
 {
   QString ret;
-  QListViewItemIterator it(selView);
+  Q3ListViewItemIterator it(selView);
   bool moderated=false;
   int count=0;
   bool isFirst=true;
 
   for(; it.current(); ++it) {
     if(!isFirst)
-      ret+=",";
+      ret+=',';
     ret+=(static_cast<GroupItem*>(it.current()))->info.name;
     isFirst=false;
     count++;
@@ -105,14 +101,14 @@ QString KNGroupSelectDialog::selectedGroups()const
 
   if (moderated && (count>=2))   // warn the user
      KMessageBox::information(parentWidget(),i18n("You are crossposting to a moderated newsgroup.\nPlease be aware that your article will not appear in any group\nuntil it has been approved by the moderators of the moderated group."),
-                              QString::null,"crosspostModeratedWarning");
+                              QString(),"crosspostModeratedWarning");
 
   return ret;
 }
 
 
 
-void KNGroupSelectDialog::slotItemSelected(QListViewItem *it)
+void KNGroupSelectDialog::slotItemSelected(Q3ListViewItem *it)
 {
   const QObject *s=sender();
 
