@@ -27,31 +27,25 @@
 #include "kmailinterface.h"
 #include "kmail_folder_interface.h"
 
-#include <kontactinterfaces/core.h>
+#include <KontactInterface/Core>
+#include <KontactInterface/Plugin>
 
-#include <kconfig.h>
-#include <kdebug.h>
-#include <kdialog.h>
-#include <kglobal.h>
-#include <kiconloader.h>
-#include <klocale.h>
-#include <kurllabel.h>
-#include <kparts/part.h>
+#include <KConfigGroup>
+#include <KDebug>
+#include <KIconLoader>
+#include <KLocale>
+#include <KUrlLabel>
 
 #include <QEvent>
 #include <QGridLayout>
-#include <QLabel>
-#include <QLayout>
-#include <QPixmap>
-#include <QToolTip>
 #include <QVBoxLayout>
 
-#include <time.h>
+#include <ctime>
 
 #define DBUS_KMAIL "org.kde.kmail"
 
-SummaryWidget::SummaryWidget( Kontact::Plugin *plugin, QWidget *parent )
-  : Kontact::Summary( parent ), mPlugin( plugin )
+SummaryWidget::SummaryWidget( KontactInterface::Plugin *plugin, QWidget *parent )
+  : KontactInterface::Summary( parent ), mPlugin( plugin )
 {
   QDBusConnection::sessionBus().registerObject( "/MailSummary", this );
   QVBoxLayout *mainLayout = new QVBoxLayout( this );
@@ -88,9 +82,13 @@ void SummaryWidget::updateSummary( bool )
 {
   // check whether we need to update the message counts
   org::kde::kmail::kmail kmail( DBUS_KMAIL, "/KMail", QDBusConnection::sessionBus() );
-  const int timeOfLastMessageCountChange = kmail.timeOfLastMessageCountChange();
-  if ( timeOfLastMessageCountChange > mTimeOfLastMessageCountUpdate ) {
-    slotUnreadCountChanged();
+  if ( kmail.isValid() ) {
+    QDBusReply<int> timeOfLastMessageCountChange = kmail.timeOfLastMessageCountChange();
+    if ( timeOfLastMessageCountChange.isValid() ) {
+      if ( timeOfLastMessageCountChange > mTimeOfLastMessageCountUpdate ) {
+        slotUnreadCountChanged();
+      }
+    }
   }
 }
 
@@ -102,7 +100,7 @@ void SummaryWidget::slotUnreadCountChanged()
     QStringList folderList = reply;
     updateFolderList( folderList );
   } else {
-    kDebug() << "Calling kmail->KMailIface->folderList() via D-Bus failed.";
+    kWarning() << "Calling kmail->KMailIface->folderList() via D-Bus failed.";
   }
   mTimeOfLastMessageCountUpdate = ::time( 0 );
 }
@@ -127,70 +125,92 @@ void SummaryWidget::updateFolderList( const QStringList &folders )
   int counter = 0;
   QStringList::ConstIterator it;
   org::kde::kmail::kmail kmail( DBUS_KMAIL, "/KMail", QDBusConnection::sessionBus() );
-  for ( it = folders.begin(); it != folders.end(); ++it ) {
-    if ( activeFolders.contains( *it ) ) {
-      QDBusReply<QString> ref = kmail.getFolder( *it );
-      if ( ref.isValid() && !ref.value().isEmpty() ) {
-        OrgKdeKmailFolderInterface folderInterface(
-          DBUS_KMAIL, "/Folder", QDBusConnection::sessionBus() );
-        QDBusReply<int> replyNumMsg = folderInterface.messages();
-        const int numMsg = replyNumMsg;
-        QDBusReply<int> replyUnreadNumMsg = folderInterface.unreadMessages();
-        const int numUnreadMsg=replyUnreadNumMsg;
+  if ( kmail.isValid() ) {
+    for ( it = folders.begin(); it != folders.end(); ++it ) {
+      if ( activeFolders.contains( *it ) ) {
+        QDBusReply<QString> ref = kmail.getFolder( *it );
+        if ( ref.isValid() && !ref.value().isEmpty() ) {
+          OrgKdeKmailFolderInterface folderInterface(
+            DBUS_KMAIL, "/Folder", QDBusConnection::sessionBus() );
+          if ( !folderInterface.isValid() ) {
+            continue;
+          }
 
-        if ( numUnreadMsg == 0 ) {
-          continue;
+          QDBusReply<int> replyNumMsg = folderInterface.messages();
+          if ( !replyNumMsg.isValid() ) {
+            continue;
+          }
+
+          const int numMsg = replyNumMsg;
+          QDBusReply<int> replyUnreadNumMsg = folderInterface.unreadMessages();
+          if ( !replyUnreadNumMsg.isValid() ) {
+            continue;
+          }
+
+          const int numUnreadMsg = replyUnreadNumMsg;
+          if ( numUnreadMsg == 0 ) {
+            continue;
+          }
+
+          // folder icon
+          QDBusReply<QString> dbusName = folderInterface.unreadIconPath();
+          QString name;
+          if ( dbusName.isValid() ) {
+            name = dbusName;
+            if ( name.isEmpty() ) {
+              name = defName;
+            }
+          } else {
+            name = defName;
+          }
+          label = new QLabel( this );
+          label->setPixmap( KIconLoader::global()->loadIcon( name, KIconLoader::Small ) );
+          label->setMaximumWidth( label->minimumSizeHint().width() );
+          label->setAlignment( Qt::AlignVCenter );
+          mLayout->addWidget( label, counter, 0 );
+          mLabels.append( label );
+
+          // folder path
+          QString folderPath;
+          QDBusReply<QString> replyFolderPath;
+          if ( config.readEntry( "ShowFullPath", true ) ) {
+            replyFolderPath= folderInterface.displayPath();
+          } else {
+            replyFolderPath= folderInterface.displayName();
+          }
+          if ( replyFolderPath.isValid() ) {
+            folderPath = replyFolderPath;
+          }
+
+          KUrlLabel *urlLabel = new KUrlLabel( *it, folderPath, this );
+          urlLabel->installEventFilter( this );
+          urlLabel->setAlignment( Qt::AlignLeft );
+          urlLabel->setWordWrap( true );
+          mLayout->addWidget( urlLabel, counter, 1 );
+          mLabels.append( urlLabel );
+
+          connect( urlLabel, SIGNAL(leftClickedUrl(const QString&)),
+                  SLOT(selectFolder(const QString&)) );
+
+          // unread of total
+          label = new QLabel( i18nc( "%1: number of unread messages "
+                                    "%2: total number of messages",
+                                    "%1 / %2", numUnreadMsg, numMsg ), this );
+          label->setAlignment( Qt::AlignLeft );
+          mLayout->addWidget( label, counter, 2 );
+          mLabels.append( label );
+
+          // tooltip
+          urlLabel->setToolTip( i18n( "<qt><b>%1</b>"
+                                      "<br/>Total: %2<br/>"
+                                      "Unread: %3</qt>",
+                                      folderPath,
+                                      numMsg,
+                                      numUnreadMsg ) );
+          //TODO: put the folder size in the tooltip
+          //so we need to add a folderSize() to the interface
+          counter++;
         }
-
-        // folder icon
-        QString name = folderInterface.unreadIconPath();
-        if ( name.isEmpty() ) {
-          name = defName;
-        }
-        label = new QLabel( this );
-        label->setPixmap( KIconLoader::global()->loadIcon( name, KIconLoader::Small ) );
-        label->setMaximumWidth( label->minimumSizeHint().width() );
-        label->setAlignment( Qt::AlignVCenter );
-        mLayout->addWidget( label, counter, 0 );
-        mLabels.append( label );
-
-        // folder path
-        QString folderPath;
-        QDBusReply<QString> replyFolderPath;
-        if ( config.readEntry( "ShowFullPath", true ) ) {
-          replyFolderPath= folderInterface.displayPath();
-        } else {
-          replyFolderPath= folderInterface.displayName();
-        }
-        folderPath = replyFolderPath;
-        KUrlLabel *urlLabel = new KUrlLabel( *it, folderPath, this );
-        urlLabel->installEventFilter( this );
-        urlLabel->setAlignment( Qt::AlignLeft );
-        urlLabel->setWordWrap( true );
-        mLayout->addWidget( urlLabel, counter, 1 );
-        mLabels.append( urlLabel );
-
-        connect( urlLabel, SIGNAL(leftClickedUrl(const QString&)),
-                 SLOT(selectFolder(const QString&)) );
-
-        // unread of total
-        label = new QLabel( i18nc( "%1: number of unread messages "
-                                   "%2: total number of messages",
-                                   "%1 / %2", numUnreadMsg, numMsg ), this );
-        label->setAlignment( Qt::AlignLeft );
-        mLayout->addWidget( label, counter, 2 );
-        mLabels.append( label );
-
-        // tooltip
-        urlLabel->setToolTip( i18n( "<qt><b>%1</b>"
-                                    "<br/>Total: %2<br/>"
-                                    "Unread: %3</qt>",
-                                    folderPath,
-                                    numMsg,
-                                    numUnreadMsg ) );
-        //TODO: put the folder size in the tooltip
-        //so we need to add a folderSize() to the interface
-        counter++;
       }
     }
   }
@@ -219,7 +239,7 @@ bool SummaryWidget::eventFilter( QObject *obj, QEvent *e )
     }
   }
 
-  return Kontact::Summary::eventFilter( obj, e );
+  return KontactInterface::Summary::eventFilter( obj, e );
 }
 
 QStringList SummaryWidget::configModules() const
