@@ -24,34 +24,23 @@
 */
 
 #include "koeventeditor.h"
-#include "koprefs.h"
-#include "koeditorgeneralevent.h"
-#include "koeditoralarms.h"
-#include "koeditorrecurrence.h"
+#include "incidencechanger.h"
 #include "koeditordetails.h"
 #include "koeditorfreebusy.h"
-#include "kogroupware.h"
+#include "koeditorgeneralevent.h"
+#include "koeditorrecurrence.h"
 #include "kohelper.h"
-#include "kodialogmanager.h"
-#include "incidencechanger.h"
+#include "kogroupware.h"
+#include "koprefs.h"
 
-#include <kcal/calendarresources.h>
-#include <kcal/resourcecalendar.h>
-#include <kcal/incidenceformatter.h>
-#include <kcal/calendarlocal.h>
+#include <KCal/CalendarLocal>
+#include <KCal/IncidenceFormatter>
 
-#include <kiconloader.h>
-#include <kdebug.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <KMessageBox>
 
-#include <QFrame>
-#include <QPixmap>
-#include <QPointer>
-#include <QLayout>
-#include <QVBoxLayout>
-#include <QHBoxLayout>
 #include <QBoxLayout>
+#include <QFrame>
+#include <QVBoxLayout>
 
 KOEventEditor::KOEventEditor( Calendar *calendar, QWidget *parent )
   : KOIncidenceEditor( QString(), calendar, parent ),
@@ -72,14 +61,14 @@ bool KOEventEditor::incidenceModified()
   Event *oldEvent = 0;
   bool modified;
 
-  if ( mEvent ) { // modification    
+  if ( mEvent ) { // modification
     oldEvent = mEvent;
   } else { // new one
     oldEvent = &mInitialEvent;
   }
 
   newEvent = oldEvent->clone();
-  fillEvent( newEvent );  
+  fillEvent( newEvent );
 
   modified = !( *newEvent == *oldEvent );
 
@@ -136,7 +125,7 @@ void KOEventEditor::init()
 void KOEventEditor::reload()
 {
   if ( mEvent ) {
-    readEvent( mEvent, true );
+    readEvent( mEvent, QDate(), true );
   }
 }
 
@@ -194,10 +183,8 @@ void KOEventEditor::setupGeneral()
   mGeneral->finishSetup();
 }
 
-void KOEventEditor::modified( int modification )
+void KOEventEditor::modified()
 {
-  Q_UNUSED( modification );
-
   // Play dumb, just reload the event. This dialog has become so complicated
   // that there is no point in trying to be smart here...
   reload();
@@ -238,19 +225,20 @@ void KOEventEditor::setupFreeBusy()
   topLayout->addWidget( mFreeBusy );
 }
 
-void KOEventEditor::editIncidence( Incidence *incidence, Calendar *calendar )
+void KOEventEditor::editIncidence( Incidence *incidence, const QDate &date, Calendar *calendar )
 {
-  Event*event = dynamic_cast<Event*>( incidence );
+  Event *event = dynamic_cast<Event *>( incidence );
   if ( event ) {
     init();
 
     mEvent = event;
     mCalendar = calendar;
-    readEvent( mEvent, false );
+    readEvent( mEvent, date, false );
   }
 
   setCaption( i18nc( "@title:window",
-                     "Edit Event : %1", KOHelper::resourceLabel( calendar, incidence ) ) );
+                     "Edit Event : %1",
+                     IncidenceFormatter::resourceString( calendar, incidence ) ) );
 }
 
 void KOEventEditor::newEvent()
@@ -317,22 +305,24 @@ bool KOEventEditor::processInput()
       if ( mIsCounter ) {
         KMessageBox::information(
           this,
-          i18n( "You didn't change the event, "
-                "thus no counter proposal has been sent to the organizer." ),
-          i18n( "No changes" ) );
+          i18nc( "@info",
+                 "You did not modify the event so no counter proposal has "
+                 "been sent to the organizer." ),
+          i18nc( "@title:window", "No Changes" ) );
       }
     } else {
-      //IncidenceChanger::assignIncidence( mEvent, event );
       fillEvent( mEvent );
       if ( mIsCounter ) {
         KOGroupware::instance()->sendCounterProposal( mCalendar, oldEvent, mEvent );
         // add dummy event at the position of the counter proposal
         Event *event = mEvent->clone();
         event->clearAttendees();
-        event->setSummary( i18n( "My counter proposal for: %1", mEvent->summary() ) );
-        mChanger->addIncidence( event );
+        event->setSummary(
+          i18nc( "@item",
+                 "My counter proposal for: %1", mEvent->summary() ) );
+        rc = mChanger->addIncidence( event, this );
       } else {
-        mChanger->changeIncidence( oldEvent, mEvent );
+        rc = mChanger->changeIncidence( oldEvent, mEvent, KOGlobals::NOTHING_MODIFIED, this );
       }
     }
     delete event;
@@ -342,13 +332,16 @@ bool KOEventEditor::processInput()
     mEvent = new Event;
     mEvent->setOrganizer( Person( KOPrefs::instance()->fullName(),
                           KOPrefs::instance()->email() ) );
+
     fillEvent( mEvent );
+
     if ( !mChanger->addIncidence( mEvent, this ) ) {
       delete mEvent;
       mEvent = 0;
       return false;
     }
   }
+
   // if "this" was deleted, freeBusy is 0 (being a guardedptr)
   if ( freeBusy ) {
     freeBusy->cancelReload();
@@ -374,13 +367,13 @@ void KOEventEditor::deleteEvent()
   reject();
 }
 
-void KOEventEditor::readEvent( Event *event, bool tmpl )
+void KOEventEditor::readEvent( Event *event, const QDate &date, bool tmpl )
 {
   if ( !event ) {
     return;
   }
 
-  mGeneral->readEvent( event, tmpl );
+  mGeneral->readEvent( event, date, tmpl );
   mRecurrence->readIncidence( event );
   if ( mFreeBusy ) {
     mFreeBusy->readIncidence( event );
@@ -424,22 +417,13 @@ bool KOEventEditor::validateInput()
   return true;
 }
 
-int KOEventEditor::msgItemDelete()
-{
-  return KMessageBox::warningContinueCancel(
-    this,
-    i18nc( "@info", "This item will be permanently deleted." ),
-    i18nc( "@title:window", "KOrganizer Confirmation" ),
-    KGuiItem( i18nc( "@action:button", "Delete" ), "edit-delete" ) );
-}
-
 void KOEventEditor::loadTemplate( CalendarLocal &cal )
 {
   Event::List events = cal.events();
   if ( events.count() == 0 ) {
     KMessageBox::error( this, i18nc( "@info", "Template does not contain a valid event." ) );
   } else {
-    readEvent( events.first(), true );
+    readEvent( events.first(), QDate(), true );
   }
 }
 
