@@ -5,6 +5,7 @@
   Copyright (C) 2003 Reinhold Kainhofer <reinhold@kainhofer.com>
   Copyright (c) 2003 Cornelius Schumacher <schumacher@kde.org>
   Copyright (c) 2008 Ron Goodheart <rong.dev@gmail.com>
+  Copyright (c) 2010 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -37,6 +38,7 @@
 #include <KCalendarSystem>
 #include <KDateTime>
 #include <KConfigGroup>
+#include <ksystemtimezone.h>
 
 #include <QDateTime>
 #include <QPainter>
@@ -231,6 +233,8 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
       mPrinter->newPage();
     }
 
+    const bool isJournal = ( (*it)->type() == "Journal" );
+
     //  PAGE Layout (same for landscape and portrait! astonishingly, it looks good with both!):
     //  +-----------------------------------+
     //  | Header:  Summary                  |
@@ -310,6 +314,7 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
                                     displayString, captionFont, textFont ), h );
     }
 
+    if ( !isJournal ) {
     // Alarms Printing
     QRect alarmBox( timesBox.left() + padding(), h + padding(),
                     timesBox.right() - padding(), lineHeight );
@@ -369,7 +374,7 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
 
     }
     h = qMax( printCaptionAndText( p, alarmBox, cap, txt, captionFont, textFont ), h );
-
+    }
     QRect organizerBox( timesBox.left() + padding(), h + padding(),
                         timesBox.right() - padding(), lineHeight );
     h = qMax( printCaptionAndText( p, organizerBox, i18n( "Organizer: " ),
@@ -382,24 +387,26 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
     QRect locationBox( timesBox );
     locationBox.setTop( timesBox.bottom() + padding() );
     locationBox.setHeight( 0 );
-    int locationBottom = drawBoxWithCaption( p, locationBox, i18n( "Location: " ),
-                                             (*it)->location(), /*sameLine=*/true,
-                                             /*expand=*/true, captionFont, textFont );
+    int locationBottom = 0;
+    if ( !isJournal ) {
+      locationBottom = drawBoxWithCaption( p, locationBox, i18n( "Location: " ),
+                                           (*it)->location(), /*sameLine=*/true,
+                                           /*expand=*/true, captionFont, textFont );
+    }
     locationBox.setBottom( locationBottom );
 
     // Now start constructing the boxes from the bottom:
     QRect categoriesBox( locationBox );
     categoriesBox.setBottom( box.bottom() );
     categoriesBox.setTop( categoriesBox.bottom() - lineHeight - 2 * padding() );
-
     QRect attendeesBox( box.left(), categoriesBox.top() - padding() - box.height() / 9,
                         box.width(), box.height() / 9 );
     QRect attachmentsBox( box.left(), attendeesBox.top() - padding() - box.height() / 9,
                           box.width() * 3 / 4 - padding(), box.height() / 9 );
-    QRect optionsBox( attachmentsBox.right() + padding(), attachmentsBox.top(), 0, 0 );
+    QRect optionsBox( isJournal ? box.left() :  attachmentsBox.right() + padding(), attachmentsBox.top(), 0, 0 );
     optionsBox.setRight( box.right() );
     optionsBox.setBottom( attachmentsBox.bottom() );
-    QRect notesBox( optionsBox.left(), locationBox.bottom() + padding(),
+    QRect notesBox( optionsBox.left(), isJournal ? ( timesBox.bottom() + padding() ) : ( locationBox.bottom() + padding() ),
                     optionsBox.width(), 0 );
     notesBox.setBottom( optionsBox.top() - padding() );
     QRect descriptionBox( notesBox );
@@ -407,7 +414,7 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
     descriptionBox.setRight( attachmentsBox.right() );
 
     // Adjust boxes depending on the show options...
-    if ( !mShowSubitemsNotes ) {
+    if ( !mShowSubitemsNotes || isJournal ) {
       descriptionBox.setRight( box.right() );
     }
     if ( !mShowAttachments || !mShowAttendees ) {
@@ -428,7 +435,7 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
         }
       }
     }
-    if ( mShowAttachments ) {
+    if ( mShowAttachments && !isJournal ) {
       if ( !mShowOptions ) {
         attachmentsBox.setRight( box.right() );
         attachmentsBox.setRight( box.right() );
@@ -445,8 +452,7 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
     if ( mShowNoteLines ) {
       drawNoteLines( p, descriptionBox, newBottom );
     }
-
-    if ( mShowSubitemsNotes ) {
+    if ( mShowSubitemsNotes && !isJournal ) {
       if ( (*it)->relations().isEmpty() || (*it)->type() != "Todo" ) {
         int notesPosition = drawBoxWithCaption( p, notesBox, i18n( "Notes:" ),
                                                 QString(), /*sameLine=*/false,
@@ -534,7 +540,7 @@ void CalPrintIncidence::print( QPainter &p, int width, int height )
       }
     }
 
-    if ( mShowAttachments ) {
+    if ( mShowAttachments && !isJournal ) {
       Attachment::List attachments = (*it)->attachments();
       QString attachmentCaption;
       if ( attachments.count() == 0 ) {
@@ -755,7 +761,7 @@ void CalPrintDay::print( QPainter &p, int width, int height )
 {
   QDate curDay( mFromDate );
 
-  KDateTime::Spec timeSpec = KOPrefs::instance()->timeSpec();
+  KDateTime::Spec timeSpec = KSystemTimeZones::local();
 
   switch ( mDayPrintType ) {
   case Filofax:
@@ -1353,7 +1359,7 @@ void CalPrintTodos::print( QPainter &p, int width, int height )
 {
   // TODO: Find a good way to guarantee a nicely designed output
   int pospriority = 0;
-  int possummary = 60;
+  int possummary = 100;
   int posdue = width - 65;
   int poscomplete = posdue - 70; //Complete column is to right of the Due column
   int lineSpacing = 15;
@@ -1375,7 +1381,6 @@ void CalPrintTodos::print( QPainter &p, int width, int height )
     outStr += i18n( "Priority" );
     p.drawText( pospriority, mCurrentLinePos - 2, outStr );
   } else {
-    possummary = 10;
     pospriority = -1;
   }
 
