@@ -121,9 +121,7 @@ class MonthCell
 class MonthGraphicsItem : public QObject, public QGraphicsItem
 {
   Q_OBJECT
-#if QT_VERSION >= 0x040600
   Q_INTERFACES(QGraphicsItem)
-#endif
 
   public:
     typedef QList<MonthGraphicsItem *> List;
