@@ -23,21 +23,11 @@
 
 #include "kcal_resourcegroupdav.h"
 #include "kcal_resourcegroupwarebaseconfig.h"
+#include "kresources_export.h"
 
 #include <kglobal.h>
 #include <klocale.h>
 
 using namespace KCal;
 
-typedef KRES::PluginFactory< ResourceGroupDav, ResourceGroupwareBaseConfig > GroupDavFactory;
-// FIXME: Use K_EXPORT_COMPONENT_FACTORY( kcal_groupdav, GroupDavFactory ); here
-// Problem: How do I insert the catalogue???
-extern "C"
-{
-  void *init_kcal_groupdav()
-  {
-    KGlobal::locale()->insertCatalogue( "kdepimresources" );
-    KGlobal::locale()->insertCatalogue( "kres_groupdav" );
-    return new GroupDavFactory;
-  }
-}
+EXPORT_KRESOURCES_PLUGIN2( ResourceGroupDav, ResourceGroupwareBaseConfig, "kdepimresources", "kres_groupdav" )
