@@ -20,16 +20,16 @@
 
 #include <typeinfo>
 
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qcheckbox.h>
+#include <QLabel>
+#include <QLayout>
+#include <QCheckBox>
 
 #include <klocale.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
 #include <klineedit.h>
 
-#include <libkcal/resourcecachedconfig.h>
+#include <kcal/resourcecachedconfig.h>
 
 #include "kcal_resourcegroupware.h"
 #include "kcal_groupwareprefsbase.h"
@@ -42,7 +42,7 @@ ResourceGroupwareConfig::ResourceGroupwareConfig( QWidget* parent,  const char*
     : KRES::ConfigWidget( parent, name )
 {
   resize( 245, 115 ); 
-  QGridLayout *mainLayout = new QGridLayout( this, 2, 2 );
+  QGridLayout *mainLayout = new QGridLayout( this );
 
   QLabel *label = new QLabel( i18n("URL:"), this );
   mainLayout->addWidget( label, 1, 0 );
@@ -61,20 +61,20 @@ ResourceGroupwareConfig::ResourceGroupwareConfig( QWidget* parent,  const char*
   mPasswordEdit->setEchoMode( KLineEdit::Password );
 
   mReloadConfig = new KCal::ResourceCachedReloadConfig( this );
-  mainLayout->addMultiCellWidget( mReloadConfig, 5, 5, 0, 1 );
+  mainLayout->addWidget( mReloadConfig, 5, 0, 1, 2 );
 
   mSaveConfig = new KCal::ResourceCachedSaveConfig( this );
-  mainLayout->addMultiCellWidget( mSaveConfig, 6, 6, 0, 1 );
+  mainLayout->addWidget( mSaveConfig, 6, 0, 1, 2 );
 }
 
 void ResourceGroupwareConfig::loadSettings( KRES::Resource *resource )
 {
-  kdDebug() << "KCal::ResourceGroupwareConfig::loadSettings()" << endl;
+  kDebug() <<"KCal::ResourceGroupwareConfig::loadSettings()";
 
   ResourceGroupware *res = static_cast<ResourceGroupware *>( resource );
   if ( res ) {
     if ( !res->prefs() ) {
-      kdError() << "No PREF" << endl;
+      kError() <<"No PREF";
       return;
     }
   
@@ -84,7 +84,7 @@ void ResourceGroupwareConfig::loadSettings( KRES::Resource *resource )
     mReloadConfig->loadSettings( res );
     mSaveConfig->loadSettings( res );
   } else {
-    kdError(5700) << "KCalResourceGroupwareConfig::loadSettings(): no KCalResourceGroupware, cast failed" << endl;
+    kError(5700) <<"KCalResourceGroupwareConfig::loadSettings(): no KCalResourceGroupware, cast failed";
   }
 }
 
@@ -98,7 +98,7 @@ void ResourceGroupwareConfig::saveSettings( KRES::Resource *resource )
     mReloadConfig->saveSettings( res );
     mSaveConfig->saveSettings( res );
   } else {
-    kdError(5700) << "KCalResourceGroupwareConfig::saveSettings(): no KCalResourceGroupware, cast failed" << endl;
+    kError(5700) <<"KCalResourceGroupwareConfig::saveSettings(): no KCalResourceGroupware, cast failed";
   }
 }
 
