@@ -146,12 +146,30 @@ QString Task::parent() const
   return mParent;
 }
 
-void Task::setDueDate( const KDateTime& date )
+void Task::setDueDate( const KDateTime &date )
 {
   mDueDate = date;
   mHasDueDate = true;
 }
 
+void Task::setDueDate( const QDate &date )
+{
+  mDueDate = KDateTime( date );
+  mHasDueDate = true;
+  mFloatingStatus = AllDay;
+}
+
+void Task::setDueDate( const QString &date )
+{
+  if ( date.length() > 10 ) {
+    // This is a date + time
+     setDueDate( stringToDateTime( date ) );
+  } else {
+     // This is only a date
+    setDueDate( stringToDate( date ) );
+  }
+}
+
 KDateTime Task::dueDate() const
 {
   return mDueDate;
@@ -225,13 +243,13 @@ bool Task::loadAttribute( QDomElement& element )
     else
       // Default
       setStatus( KCal::Incidence::StatusNone );
-  } else if ( tagName == "due-date" )
-    setDueDate( stringToDateTime( element.text() ) );
-  else if ( tagName == "parent" )
+  } else if ( tagName == "due-date" ) {
+    setDueDate( element.text() );
+  } else if ( tagName == "parent" ) {
     setParent( element.text() );
-  else if ( tagName == "x-completed-date" )
+  } else if ( tagName == "x-completed-date" ) {
     setCompletedDate( stringToDateTime( element.text() ) );
-  else if ( tagName == "start-date" ) {
+  } else if ( tagName == "start-date" ) {
     setHasStartDate( true );
     setStartDate( element.text() );
   } else
@@ -279,14 +297,21 @@ bool Task::saveAttributes( QDomElement& element ) const
     break;
   }
 
-  if ( hasDueDate() )
-    writeString( element, "due-date", dateTimeToString( dueDate() ) );
+  if ( hasDueDate() ) {
+    if ( mFloatingStatus == HasTime ) {
+      writeString( element, "due-date", dateTimeToString( dueDate() ) );
+    } else {
+      writeString( element, "due-date", dateToString( dueDate().date() ) );
+    }
+  }
 
-  if ( !parent().isNull() )
+  if ( !parent().isNull() ) {
     writeString( element, "parent", parent() );
+  }
 
-  if ( hasCompletedDate() && percentCompleted() == 100)
+  if ( hasCompletedDate() && percentCompleted() == 100 ) {
     writeString( element, "x-completed-date", dateTimeToString( completedDate() ) );
+  }
 
   return true;
 }
@@ -350,21 +375,32 @@ void Task::setFields( const KCal::Todo* task )
   setStatus( task->status() );
   setHasStartDate( task->hasStartDate() );
 
-  if ( task->hasDueDate() )
-    setDueDate( localToUTC( task->dtDue() ) );
-  else
+  if ( task->hasDueDate() ) {
+    if ( task->allDay() ) {
+      // This is a floating task. Don't timezone move this one
+      mFloatingStatus = AllDay;
+      setDueDate( KDateTime( task->dtDue().date() ) );
+    } else {
+      mFloatingStatus = HasTime;
+      setDueDate( localToUTC( task->dtDue() ) );
+    }
+  } else {
     mHasDueDate = false;
-  if ( task->relatedTo() )
-    setParent( task->relatedTo()->uid() );
-  else if ( !task->relatedToUid().isEmpty() )
-    setParent( task->relatedToUid( ) );
-  else
-    setParent( QString() );
+  }
 
-  if ( task->hasCompletedDate() && task->percentComplete() == 100 )
+  if ( task->relatedTo() ) {
+    setParent( task->relatedTo()->uid() );
+  } else if ( !task->relatedToUid().isEmpty() ) {
+    setParent( task->relatedToUid( ) );
+  } else{
+    setParent( QString() );
+  }
+
+  if ( task->hasCompletedDate() && task->percentComplete() == 100 ) {
     setCompletedDate( localToUTC( task->completed() ) );
-  else
+  } else {
     mHasCompletedDate = false;
+  }
 }
 
 void Task::decideAndSetPriority()
