@@ -34,10 +34,10 @@ unsigned int KPIM::ProgressManager::uID = 42;
 ProgressItem::ProgressItem( ProgressItem *parent, const QString &id,
                             const QString &label, const QString &status,
                             bool canBeCanceled, bool usesCrypto )
-  :mId( id ), mLabel( label ), mStatus( status ), mParent( parent ),
-   mCanBeCanceled( canBeCanceled ), mProgress( 0 ), mTotal( 0 ),
-   mCompleted( 0 ), mWaitingForKids( false ), mCanceled( false ),
-   mUsesCrypto( usesCrypto )
+  : mId( id ), mLabel( label ), mStatus( status ), mParent( parent ),
+    mCanBeCanceled( canBeCanceled ), mProgress( 0 ), mTotal( 0 ),
+    mCompleted( 0 ), mWaitingForKids( false ), mCanceled( false ),
+    mUsesCrypto( usesCrypto ), mUsesBusyIndicator( false )
 {
 }
 
@@ -125,6 +125,12 @@ void ProgressItem::setUsesCrypto( bool v )
   emit progressItemUsesCrypto( this, v );
 }
 
+void ProgressItem::setUsesBusyIndicator( bool useBusyIndicator )
+{
+  mUsesBusyIndicator = useBusyIndicator;
+  emit progressItemUsesBusyIndicator( this, useBusyIndicator );
+}
+
 // ======================================
 
 struct ProgressManagerPrivate {
@@ -178,6 +184,8 @@ ProgressItem *ProgressManager::createProgressItemImpl( ProgressItem *parent,
               this, SIGNAL( progressItemLabel(KPIM::ProgressItem*, const QString&) ) );
     connect ( t, SIGNAL( progressItemUsesCrypto(KPIM::ProgressItem*, bool) ),
               this, SIGNAL( progressItemUsesCrypto(KPIM::ProgressItem*, bool) ) );
+     connect ( t, SIGNAL( progressItemUsesBusyIndicator(KPIM::ProgressItem*, bool) ),
+               this, SIGNAL( progressItemUsesBusyIndicator(KPIM::ProgressItem*, bool) ) );
 
     emit progressItemAdded( t );
   } else {
@@ -221,7 +229,12 @@ ProgressItem *ProgressManager::singleItem() const
   ProgressItem *item = 0;
   QHash< QString, ProgressItem* >::const_iterator it = mTransactions.constBegin();
   while ( it != mTransactions.constEnd() ) {
-    if ( !(*it)->parent() ) { // if it's a top level one, only those count
+
+    // No single item for progress possible, as one of them is a busy indicator one.
+    if ( (*it)->usesBusyIndicator() )
+      return 0;
+
+    if ( !(*it)->parent() ) {             // if it's a top level one, only those count
       if ( item ) {
         return 0; // we found more than one
       } else {
